@@ -35,32 +35,33 @@
     items.label <- paste(items.label, ":", sep = "")
 
     if (graphics & capabilities("tcltk")) {
+        requireNamespace("tcltk", quietly = TRUE)
         ppp <- NULL ## only to avoid a NOTE at package check time
 
         string.to.vector <- function(string.of.indices) {
             as.numeric(strsplit(string.of.indices, split = " ")[[1]])
         }
-        base <- tktoplevel(takefocus = 1)
-        tkwm.title(base, title)
-        tkwm.geometry(base, windowPos)
-        tkwm.resizable(base, 0, 0)
+        base <- tcltk::tktoplevel(takefocus = 1)
+        tcltk::tkwm.title(base, title)
+        tcltk::tkwm.geometry(base, windowPos)
+        tcltk::tkwm.resizable(base, 0, 0)
 
-        right.frm <- tkframe(base)
-        left.frm <- tkframe(base)
+        right.frm <- tcltk::tkframe(base)
+        left.frm <- tcltk::tkframe(base)
 
-        items.list <- as.character(tclVar(paste("{", paste(vec.to.pickfrom,
+        items.list <- as.character(tcltk::tclVar(paste("{", paste(vec.to.pickfrom,
                                                            collapse = "} {"),
                                                 "}", sep = "")))
-        items.frm <- tkframe(left.frm)
+        items.frm <- tcltk::tkframe(left.frm)
 
-        items.label <- tklabel(items.frm,
+        items.label <- tcltk::tklabel(items.frm,
                                text = items.label,
                                anchor = "w",
                                justify = "left")
-        tkgrid(items.label, row = 0, columnspan = 2, sticky = "w")
+        tcltk::tkgrid(items.label, row = 0, columnspan = 2, sticky = "w")
         items.height <- min(list.height, ni)
         items.width <- max(8, max(nchar(vec.to.pickfrom)))
-        items <- tklistbox(items.frm,
+        items <- tcltk::tklistbox(items.frm,
                            listvar = items.list,
                            bg = "grey50",
                            selectmode = "extended",
@@ -68,10 +69,10 @@
                            font = listFont,
                            width = items.width,
                            height = items.height)
-        tkgrid(items, row = 1, column = 0)
-        preserve.order <- tclVar(as.numeric(preserve.order))
-        buttons.frm <- tkframe(left.frm)
-        buttonA <- tkradiobutton(buttons.frm,
+        tcltk::tkgrid(items, row = 1, column = 0)
+        preserve.order <- tcltk::tclVar(as.numeric(preserve.order))
+        buttons.frm <- tcltk::tkframe(left.frm)
+        buttonA <- tcltk::tkradiobutton(buttons.frm,
                                  text = "Sort sets in\nthe above order\nupon \"Add\"",
                                  justify = "left",
                                  variable = preserve.order,
@@ -79,7 +80,7 @@
                                  command = function(){NULL}
                                  )
 
-        buttonB <- tkradiobutton(buttons.frm,
+        buttonB <- tcltk::tkradiobutton(buttons.frm,
                                  text = "Place\nnewly added\nitems last",
                                  justify = "left",
                                  variable = preserve.order,
@@ -88,27 +89,27 @@
                                  )
 
         if (items.scrollbar && (length(vec) > items.height)) {
-            items.scrollbar <- tkscrollbar(items.frm,
+            items.scrollbar <- tcltk::tkscrollbar(items.frm,
                                            orient = "vertical",
                                            repeatinterval = 1,
                                            command = function(...) {
-                                               tkyview(items, ...)
+                                               tcltk::tkyview(items, ...)
                                            })
-            tkconfigure(items, yscrollcommand = function(...) {
-                tkset(items.scrollbar, ...)
-                xy <- string.to.vector(tclvalue(tkget(items.scrollbar)))
-                tkyview.moveto(items, xy[1])
+            tcltk::tkconfigure(items, yscrollcommand = function(...) {
+                tcltk::tkset(items.scrollbar, ...)
+                xy <- string.to.vector(tcltk::tclvalue(tcltk::tkget(items.scrollbar)))
+                tcltk::tkyview.moveto(items, xy[1])
             })
-            tkgrid(items.scrollbar, row = 1, column = 1, sticky = "ns")
+            tcltk::tkgrid(items.scrollbar, row = 1, column = 1, sticky = "ns")
         }
-        tkpack(buttonA, buttonB, pady = 1, padx = 5, side = "top",
+        tcltk::tkpack(buttonA, buttonB, pady = 1, padx = 5, side = "top",
                anchor = "nw")
-        tkpack(items.frm, buttons.frm,
+        tcltk::tkpack(items.frm, buttons.frm,
                pady = 1, padx = 5, side = "top")
 
-        tkpack(left.frm, side = "top", expand = "true", anchor = "n")
+        tcltk::tkpack(left.frm, side = "top", expand = "true", anchor = "n")
 
-        sets.frm <- tkframe(right.frm)
+        sets.frm <- tcltk::tkframe(right.frm)
         setframe <- list()
         label <- list()
         setlabeltext <- list()
@@ -124,46 +125,47 @@
         Rtkset <- list()
         subset.height <- min(list.height - 5, ni)
         for (i in 1:nsets) {
-            tkset[[i]] <- tclVar("")
-            TCLlabel[[i]] <- tclVar(setlabels[[i]])
-            setframe[[i]] <- tkframe(sets.frm,
+            tkset[[i]] <- tcltk::tclVar("")
+            TCLlabel[[i]] <- tcltk::tclVar(setlabels[[i]])
+            setframe[[i]] <- tcltk::tkframe(sets.frm,
                                      width = 250,
                                      relief = "groove",
                                      borderwidth = 2)
-            label[[i]] <- tklabel(setframe[[i]], text = setlabels[[i]])
+            label[[i]] <- tcltk::tklabel(setframe[[i]], text = setlabels[[i]])
             listvarname[[i]] <- as.character(tkset[[i]])
-            listbox[[i]] <- tklistbox(setframe[[i]],
+            listbox[[i]] <- tcltk::tklistbox(setframe[[i]],
                                       listvar = listvarname[[i]],
                                       bg = "white",
                                       height = subset.height,
                                       font = listFont,
                                       width = items.width,
                                       selectmode = "extended")
-            labelbox[[i]] <- tkframe(setframe[[i]], width = 250)
-            setlabeltext[[i]] <- tklabel(labelbox[[i]], text =
+            labelbox[[i]] <- tcltk::tkframe(setframe[[i]], width = 250)
+            setlabeltext[[i]] <- tcltk::tklabel(labelbox[[i]], text =
                                          paste(labels.prompt, ":", sep = ""))
         }
         add.cmd <- deparse(function() {
-            set[[ppp]] <- match(Tcl.to.R(tclvalue(tkset[[ppp]])),
+            set[[ppp]] <- match(Tcl.to.R(tcltk::tclvalue(tkset[[ppp]])),
                                 vec.to.pickfrom)
             set[[ppp]] <- union(set[[ppp]], 1 +
-                                string.to.vector(tclvalue(tkcurselection(items))))
-            if (as.logical(tclObj(preserve.order)))
+                            string.to.vector(tcltk::tclvalue(tcltk::tkcurselection(items))))
+            if (as.logical(tcltk::tclObj(preserve.order)))
                 set[[ppp]] <- sort(set[[ppp]])
-            tclvalue(tkset[[ppp]]) <- R.to.Tcl(vec.to.pickfrom[set[[ppp]]])
-            tkconfigure(add.but[[ppp]], state = "disabled")
+            tcltk::tclvalue(tkset[[ppp]]) <- R.to.Tcl(vec.to.pickfrom[set[[ppp]]])
+            tcltk::tkconfigure(add.but[[ppp]], state = "disabled")
         })
         remove.cmd <- deparse(function() {
-            Rtkset[[ppp]] <- Tcl.to.R(tclvalue(tkset[[ppp]]))
-            out <- 1 + string.to.vector(tclvalue(tkcurselection(listbox[[ppp]])))
+            Rtkset[[ppp]] <- Tcl.to.R(tcltk::tclvalue(tkset[[ppp]]))
+            out <- 1 +
+                string.to.vector(tcltk::tclvalue(tcltk::tkcurselection(listbox[[ppp]])))
             if (length(Rtkset[[ppp]]) == length(out))
-                tclvalue(tkset[[ppp]]) <- ""
-            else tclvalue(tkset[[ppp]]) <- R.to.Tcl(Rtkset[[ppp]][-out])
-            tkconfigure(remove.but[[ppp]], state = "disabled")
-            tkselection.clear(listbox[[ppp]], "0", "end")
+                tcltk::tclvalue(tkset[[ppp]]) <- ""
+            else tcltk::tclvalue(tkset[[ppp]]) <- R.to.Tcl(Rtkset[[ppp]][-out])
+            tcltk::tkconfigure(remove.but[[ppp]], state = "disabled")
+            tcltk::tkselection.clear(listbox[[ppp]], "0", "end")
         })
         for (i in 1:nsets) {
-            add.but[[i]] <- tkbutton(setframe[[i]], text = "Add",
+            add.but[[i]] <- tcltk::tkbutton(setframe[[i]], text = "Add",
                                      fg = "darkgreen",
                                      disabledforeground = "darkgrey",
                                      width = 10,
@@ -171,7 +173,7 @@
                                      command = eval(parse(text = gsub("ppp",
                                                           as.character(i),
                                                           add.cmd))))
-            remove.but[[i]] <- tkbutton(setframe[[i]], text = "Remove",
+            remove.but[[i]] <- tcltk::tkbutton(setframe[[i]], text = "Remove",
                                         fg = "darkred",
                                         disabledforeground = "darkgrey",
                                         width = 10,
@@ -179,73 +181,74 @@
                                         command = eval(parse(text = gsub("ppp",
                                                              as.character(i),
                                                              remove.cmd))))
-            labelentry[[i]] <- tkentry(labelbox[[i]],
+            labelentry[[i]] <- tcltk::tkentry(labelbox[[i]],
                                        textvariable = as.character(TCLlabel[[i]]),
                                        font = labelFont,
                                        bg = "white")
             if (edit.setlabels) {
-                tkpack(setlabeltext[[i]], labelentry[[i]], side = "top",
+                tcltk::tkpack(setlabeltext[[i]], labelentry[[i]], side = "top",
                        anchor = "w")
             }
-            tkpack(label[[i]], add.but[[i]], remove.but[[i]], listbox[[i]],
+            tcltk::tkpack(label[[i]], add.but[[i]], remove.but[[i]], listbox[[i]],
                    labelbox[[i]], side = "top", padx = 5, pady = 5)
-            tkpack(setframe[[i]], side = "left", padx = 3, pady = 10)
+            tcltk::tkpack(setframe[[i]], side = "left", padx = 3, pady = 10)
         }
         fun1 <- deparse(function() {
-            if (tclvalue(tkcurselection(listbox[[ppp]])) != "") {
+            if (tcltk::tclvalue(tcltk::tkcurselection(listbox[[ppp]])) != "") {
                 for (j in 1:nsets) {
-                    tkconfigure(add.but[[j]], state = "disabled")
+                    tcltk::tkconfigure(add.but[[j]], state = "disabled")
                 }
-                tkconfigure(remove.but[[ppp]], state = "normal")
+                tcltk::tkconfigure(remove.but[[ppp]], state = "normal")
             }
             for (j in (1:nsets)[-ppp]) {
-                tkconfigure(remove.but[[j]], state = "disabled")
+                tcltk::tkconfigure(remove.but[[j]], state = "disabled")
             }
-            tkfocus(listbox[[ppp]])
+            tcltk::tkfocus(listbox[[ppp]])
         })
         for (i in 1:nsets) {
-            tkbind(listbox[[i]], "<<ListboxSelect>>",
+            tcltk::tkbind(listbox[[i]], "<<ListboxSelect>>",
                    eval(parse(text = gsub("ppp", as.character(i), fun1))))
         }
-        tkbind(items, "<<ListboxSelect>>", function() {
-            items.selected <- vec.to.pickfrom[1 + string.to.vector(tclvalue(tkcurselection(items)))]
+        tcltk::tkbind(items, "<<ListboxSelect>>", function() {
+            items.selected <- vec.to.pickfrom[1 +
+                         string.to.vector(tcltk::tclvalue(tcltk::tkcurselection(items)))]
             for (i in 1:nsets) {
-                set[[i]] <- Tcl.to.R(tclvalue(tkset[[i]]))
+                set[[i]] <- Tcl.to.R(tcltk::tclvalue(tkset[[i]]))
                 if (setequal(items.selected, intersect(items.selected,
                                                        set[[i]]))) {
-                    tkconfigure(add.but[[i]], state = "disabled")
+                    tcltk::tkconfigure(add.but[[i]], state = "disabled")
                 }
-                else tkconfigure(add.but[[i]], state = "normal")
-                tkconfigure(remove.but[[i]], state = "disabled")
+                else tcltk::tkconfigure(add.but[[i]], state = "normal")
+                tcltk::tkconfigure(remove.but[[i]], state = "disabled")
             }
         })
-        tkbind(items, "<Button-1>", function() tkfocus(items))
-        buttons.frame <- tkframe(right.frm)
-        OK <- tclVar(0)
-        ok.but <- tkbutton(buttons.frame, text = "OK", width = 10,
+        tcltk::tkbind(items, "<Button-1>", function() tcltk::tkfocus(items))
+        buttons.frame <- tcltk::tkframe(right.frm)
+        OK <- tcltk::tclVar(0)
+        ok.but <- tcltk::tkbutton(buttons.frame, text = "OK", width = 10,
                            command = function() {
-                               tkdestroy(base)
-                               tclvalue(OK) <- 1
+                               tcltk::tkdestroy(base)
+                               tcltk::tclvalue(OK) <- 1
                            })
-        tkconfigure(ok.but, state = "normal")
-        cancel.but <- tkbutton(buttons.frame, text = "Cancel", width = 10,
+        tcltk::tkconfigure(ok.but, state = "normal")
+        cancel.but <- tcltk::tkbutton(buttons.frame, text = "Cancel", width = 10,
                                command = function() {
-                                   tkdestroy(base)
+                                   tcltk::tkdestroy(base)
                                })
-        tkpack(ok.but, cancel.but, side = "left", padx = 20, pady = 20)
-        tkpack(sets.frm, buttons.frame, side = "top")
-        tkpack(left.frm, side = "left", anchor = "nw", padx = 1)
-        tkpack(right.frm, anchor = "ne")
-        tkwait.window(base)
-        .Tcl("update idletasks")
-        if (tclvalue(OK) == "1") {
+        tcltk::tkpack(ok.but, cancel.but, side = "left", padx = 20, pady = 20)
+        tcltk::tkpack(sets.frm, buttons.frame, side = "top")
+        tcltk::tkpack(left.frm, side = "left", anchor = "nw", padx = 1)
+        tcltk::tkpack(right.frm, anchor = "ne")
+        tcltk::tkwait.window(base)
+        tcltk::.Tcl("update idletasks")
+        if (tcltk::tclvalue(OK) == "1") {
             sets <- lapply(tkset, function(set) {
-                match(Tcl.to.R(tclvalue(set)), vec.to.pickfrom)
+                match(Tcl.to.R(tcltk::tclvalue(set)), vec.to.pickfrom)
             })
             if (any(sapply(sets, length) == 0)) {
                 warning(warningText)
             }
-            labels <- lapply(TCLlabel, tclvalue)
+            labels <- lapply(TCLlabel, tcltk::tclvalue)
             names(sets) <- labels
             result <- sets
         } else return(NULL)
